@@ -1,13 +1,12 @@
 from gongish import Application as GongishApp
 from cytra.db import DatabaseAppMixin
 from cytra.auth import AuthAppMixin
+from cytra.cors import CORS
 
 
 class CytraAppBase(GongishApp):
     # Reserved CORS config
-    __cors_allow_methods__: set = set()
-    __cors_allow_headers__: set = set(("content-type",))
-    __cors_expose_headers__: set = set(("content-type",))
+    cors: CORS = None
 
     @staticmethod
     def format_json(request, response, indent=None):
@@ -19,6 +18,12 @@ class CytraAppBase(GongishApp):
 
     __default_formatter__ = format_json
 
+    def __init__(self):
+        super().__init__()
+        self.cors = CORS()
+        self.cors.allow_headers.add("content-type")
+        self.cors.expose_headers.add("content-type")
+
     def setup(self):
         pass
 
